@@ -237,6 +237,7 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 				KAction *tmp = new KAction( this );
 				tmp->setIcon( KIcon("dialog-ok") );
 				tmp->setText( str);
+				tmp->setObjectName( QString::number(i) );
 				connect(tmp, SIGNAL(triggered(bool)), SLOT(slotSelectResource()));
 				actionSelectResource->addAction(tmp);
 			}
@@ -252,6 +253,7 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 				KAction *tmp = new KAction(this);
 				tmp->setIcon( KIcon(iconSet) );
 				tmp->setText( str );
+				tmp->setObjectName( QString::number(i) );
 				connect(tmp, SIGNAL(triggered(bool)), SLOT(slotSelectResource()));
 				actionSelectResource->addAction ( tmp );
 			}
@@ -359,10 +361,7 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 					m.setDirection( Kopete::Message::Internal );
 					m.setImportance(Kopete::Message::Low);
 
-					if ( account()->mergeMessages() )
-						mManager->appendMessage ( m, QString() );
-					else
-						mManager->appendMessage ( m, message.from().resource () );
+					mManager->appendMessage ( m, message.from().resource () );
 				}
 			}
 		}
@@ -447,10 +446,7 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 	// append message to (eventually new) manager and preselect the originating resource
 	if ( newMessage )
 	{
-		if ( account()->mergeMessages() )
-			mManager->appendMessage ( *newMessage, QString() );
-		else
-			mManager->appendMessage ( *newMessage, message.from().resource () );
+		mManager->appendMessage ( *newMessage, message.from().resource () );
 
 		delete newMessage;
 	}
@@ -474,10 +470,7 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 		msg.setDirection( Kopete::Message::Inbound );
 		msg.setRequestedPlugin( viewPlugin );
 
-		if ( account()->mergeMessages() )
-			mManager->appendMessage ( msg, QString() );
-		else
-			mManager->appendMessage ( msg, message.from().resource () );
+		mManager->appendMessage ( msg, message.from().resource () );
 	}
 }
 
@@ -933,7 +926,7 @@ JabberChatSession *JabberContact::manager ( const QString &resource, Kopete::Con
 		for ( ; it != end ; ++it )
 		{
 			JabberChatSession *mManager = *it;
-			if ( mManager->resource().isEmpty () || ( mManager->resource () == resource ) )
+			if ( account()->mergeMessages () || mManager->resource().isEmpty () || ( mManager->resource () == resource ) )
 			{
 				// we found a matching manager, return this one
 				kDebug(JABBER_DEBUG_GLOBAL) << "Found an existing message manager for this resource.";
@@ -1178,7 +1171,8 @@ void JabberContact::slotSelectResource ()
 	}
 	else
 	{
-		QString selectedResource = static_cast<const KAction *>(sender())->text();
+		// use iconText() instead of text(), because we need stripped value without '&'
+		QString selectedResource = static_cast<const KAction *>(sender())->iconText();
 
 		kDebug (JABBER_DEBUG_GLOBAL) << "Moving to resource " << selectedResource;
 
